@@ -1,6 +1,7 @@
 /** @typedef {import("@jridgewell/trace-mapping").SourceMapInput} SourceMapInput */
 /** @typedef {import("terser").FormatOptions} TerserFormatOptions */
 /** @typedef {import("terser").MinifyOptions} TerserOptions */
+/** @typedef {import("terser").CompressOptions} TerserCompressOptions */
 /** @typedef {import("terser").ECMA} TerserECMA */
 /** @typedef {import("./index.js").ExtractCommentsOptions} ExtractCommentsOptions */
 /** @typedef {import("./index.js").ExtractCommentsFunction} ExtractCommentsFunction */
@@ -219,7 +220,7 @@ async function terserMinify(
 
   /**
    * @param {PredefinedOptions & TerserOptions} [terserOptions={}]
-   * @returns {TerserOptions & { sourceMap: undefined } & ({ output: TerserFormatOptions & { beautify: boolean } } | { format: TerserFormatOptions & { beautify: boolean } })}
+   * @returns {TerserOptions & { sourceMap: undefined } & { compress: TerserCompressOptions } & ({ output: TerserFormatOptions & { beautify: boolean } } | { format: TerserFormatOptions & { beautify: boolean } })}
    */
   const buildTerserOptions = (terserOptions = {}) => {
     // Need deep copy objects to avoid https://github.com/terser/terser/issues/366
@@ -228,6 +229,8 @@ async function terserMinify(
       compress:
         typeof terserOptions.compress === "boolean"
           ? terserOptions.compress
+            ? {}
+            : false
           : { ...terserOptions.compress },
       // ecma: terserOptions.ecma,
       // ie8: terserOptions.ie8,
@@ -280,6 +283,21 @@ async function terserMinify(
     );
   }
 
+  if (terserOptions.compress) {
+    // More optimizations
+    if (typeof terserOptions.compress.ecma === "undefined") {
+      terserOptions.compress.ecma = terserOptions.ecma;
+    }
+
+    // https://github.com/webpack/webpack/issues/16135
+    if (
+      terserOptions.ecma === 5 &&
+      typeof terserOptions.compress.arrows === "undefined"
+    ) {
+      terserOptions.compress.arrows = false;
+    }
+  }
+
   const [[filename, code]] = Object.entries(input);
   const result = await minify({ [filename]: code }, terserOptions);
 
@@ -536,7 +554,7 @@ uglifyJsMinify.getMinimizerVersion = () => {
 async function swcMinify(input, sourceMap, minimizerOptions) {
   /**
    * @param {PredefinedOptions & import("@swc/core").JsMinifyOptions} [swcOptions={}]
-   * @returns {import("@swc/core").JsMinifyOptions & { sourceMap: undefined }}
+   * @returns {import("@swc/core").JsMinifyOptions & { sourceMap: undefined } & { compress: import("@swc/core").TerserCompressOptions }}
    */
   const buildSwcOptions = (swcOptions = {}) => {
     // Need deep copy objects to avoid https://github.com/terser/terser/issues/366
@@ -545,6 +563,8 @@ async function swcMinify(input, sourceMap, minimizerOptions) {
       compress:
         typeof swcOptions.compress === "boolean"
           ? swcOptions.compress
+            ? {}
+            : false
           : { ...swcOptions.compress },
       mangle:
         swcOptions.mangle == null
@@ -574,6 +594,21 @@ async function swcMinify(input, sourceMap, minimizerOptions) {
     swcOptions.sourceMap = true;
   }
 
+  if (swcOptions.compress) {
+    // More optimizations
+    if (typeof swcOptions.compress.ecma === "undefined") {
+      swcOptions.compress.ecma = swcOptions.ecma;
+    }
+
+    // https://github.com/webpack/webpack/issues/16135
+    if (
+      swcOptions.ecma === 5 &&
+      typeof swcOptions.compress.arrows === "undefined"
+    ) {
+      swcOptions.compress.arrows = false;
+    }
+  }
+
   const [[filename, code]] = Object.entries(input);
   const result = await swc.minify(code, swcOptions);
 
